16.149. cdist-type__xymon_config(7) — cdist 6.1.1 documentation

# 16.149. cdist-type__xymon_config(7)

## 16.149.1. NAME

cdist-type__xymon_config - Deploy a Xymon configuration-directory

## 16.149.2. DESCRIPTION

This cdist type deploys a full Xymon configuration directory from the files-dir to the host. This type requires an installed Xymon server, e.g. deployed by __xymon_server.

WARNING: This type _replaces_ the /etc/xymon/-directory! The previous contents is replaced/deleted!

## 16.149.3. REQUIRED PARAMETERS

confdir
  The directory in ./files/ that contains the /etc/xymon/-content to be deployed.

## 16.149.4. OPTIONAL PARAMETERS

owner
  passed as-is as --owner to __rsync
group
  passed as-is as --group to __rsync

## 16.149.5. OPTIONAL MULTIPLE PARAMETERS

rsync-opts
  identical to __rsync type, only ---options are supported

## 16.149.6. REQUIRED FILES

The directory specified by confdir has to contain a valid xymon-configuration (/etc/xymon/) _plus_ the ext/-directory that normally resides in /usr/lib/xymon/server/.

## 16.149.7. EXAMPLES

    __xymon_config --confdir=xymon.example.com
    # this will replace /etc/xymon/ on the target host with
    # the contents from __xymon_config/files/xymon.example.com/

    ## the same but set ownership to `xymon:xymon` and exclude
    ## the `netrc`-file:
    __xymon_config --confdir=xymon.example.com \
       --owner xymon --group xymon \
       --rsync-opts "exclude=netrc"

## 16.149.8. SEE ALSO

cdist__xymon_server(7), cdist__rsync(7), xymon(7)

## 16.149.9. AUTHORS

Thomas Eckert <tom--@--it-eckert.de>

## 16.149.10. COPYING

Copyright (C) 2018-2019 Thomas Eckert. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.